import React from "react";
import "./App.css";
import { Viewer } from "@grapecity/activereports-react";
import { PdfExport,HtmlExport,TabularDataExport, XlsxExport } from "@grapecity/activereports";

function App() {
  const viewerRef = React.useRef(null);
  var currentReport = null;
  React.useEffect(() => {
    if (!viewerRef.current) return;
    var printButton = {
      key: "$print",
      iconCssClass: "mdi mdi-printer",
      text: "",
      enabled: true,
      action: function (item) {
        console.log("Print!");
        if (currentReport.parameters.PageNumbers) {
          currentReport.parameters.PageNumbers.values =
            currentReport.parameters.PageNumbers.validValues.map(
              (item) => item.value
            );
        }
        currentReport.run().then((doc) => {
          doc.print();
        });
      },
    };

    viewerRef.current.Viewer.toolbar.updateItem("$print", printButton);
  }, []);

  const reportLoaded = (e) => {
    currentReport = e.report;
    var panelStore = viewerRef.current.Viewer._viewer._panelsStore;
      panelStore.state.panels[3].component.props.startExport = (
        ...args
      ) => {
        //args contain information on export type and export settings form the export panel
        console.log(args);
        exportReport(args[0],args[1]);
           
  };
  function convertToPdfExportSettings(viewerExportSettings){
    return {
      autoPrint:viewerExportSettings["autoPrint"],
      info:{
        author:viewerExportSettings["author"],
        keywords:viewerExportSettings["keywords"],
        subject:viewerExportSettings["subject"],
        title:viewerExportSettings["title"]
      },
      pdfVersion:viewerExportSettings["pdfVersion"],
      security:{
        ownerPassword:viewerExportSettings["ownerPassword"],
        userPassword:viewerExportSettings["userPassword"],
        permissions:{
          annotating:viewerExportSettings["annotating"],
          contentAccessibility:viewerExportSettings["contentAccessibility"],
          copying:viewerExportSettings["copying"],
          documentAssembly:viewerExportSettings["documentAssembly"],
          modifying:viewerExportSettings["modifying"],
          printing:viewerExportSettings["printing"]
        }
      },
      filename:viewerExportSettings["filename"]
    };
  }
  function converToHtmlExportSettings(viewerExportSettings){
    return {
      autoPrint:viewerExportSettings["autoPrint"],      
      embedImages:viewerExportSettings["embedImages"],
      multiPage:viewerExportSettings["multiPage"],
      outputType:viewerExportSettings["outputType"],
      title:viewerExportSettings["title"],
      filename:viewerExportSettings["filename"]
    }
  }
  function converToTabularDataExportSettings(viewerExportSettings){
    return {
      format:viewerExportSettings["format"],
      colSeparator:viewerExportSettings["colSeparator"],      
      outputType:viewerExportSettings["outputType"],
      quotationSymbol:viewerExportSettings["quotationSymbol"],
      rowSeparator:viewerExportSettings["rowSeparator"],
      tableSeparator:viewerExportSettings["tableSeparator"],
      filename:viewerExportSettings["filename"]
    }
  }

  function converToXlsxExportSettings(viewerExportSettings){
    return {
      format:viewerExportSettings["format"],
      info:{
        creator:viewerExportSettings["creator"]
      },      
      pageSettings:{
        orientation:viewerExportSettings["orientation"],
        size:viewerExportSettings["size"]
      },
      password:viewerExportSettings["password"],
      sheetName:viewerExportSettings["sheetName"],
      filename:viewerExportSettings["filename"]
    }
  }

  function exportReport(exportType,viewerExportSettings){   
    if (currentReport.parameters.PageNumbers) {
      currentReport.parameters.PageNumbers.values =
        currentReport.parameters.PageNumbers.validValues.map(
          (item) => item.value
        );
    }
    currentReport.run().then((doc) => {
      if (exportType === "pdf") {
        var pdfExportSettings=convertToPdfExportSettings(viewerExportSettings);
        PdfExport.exportDocument(doc, pdfExportSettings).then((result) => {
          result.download(viewerExportSettings.filename);
        });
      }
      else if (exportType === "html") {
        var htmlExportSettings=converToHtmlExportSettings(viewerExportSettings);
        HtmlExport.exportDocument(doc, htmlExportSettings).then((result) => {
          result.download(viewerExportSettings.filename);
        });
      }
      else if (exportType === "tabular-data") {
        var tabularDataExportSettings=converToTabularDataExportSettings(viewerExportSettings);
        TabularDataExport.exportDocument(doc, tabularDataExportSettings).then((result) => {
          result.download(viewerExportSettings.filename);
        });
      }
      else if (exportType === "xlsx") {
        var xlsxExportSettings=converToXlsxExportSettings(viewerExportSettings);
        XlsxExport.exportDocument(doc, xlsxExportSettings).then((result) => {
          result.download(viewerExportSettings.filename);
        });
      }
    });
    return true;
  }; 
  }
  return (
    <div id="viewer-host">
      <Viewer
        ref={viewerRef}
        report={{ Uri: "PageNumberReport.rdlx-json" }}
        reportLoaded={reportLoaded}
      />
    </div>
  );
}
export default App;
